class WorkChart(PWReportPage):
	def init(self):
		super(WorkChart, self).init()
		self.project				= None
		self.intervalUnit			= 0
		self.iterIntervalStartDate	= None
		self.contentMode			= 0
		self.withObjective 			= True
		self.withPhases             = True
		self.withMasterResources	= True
		self.firstColor			    = None
		self.fifthColor  		    = None
		self.fourthColor     		= None
		self.thirdColor 		    = None
		self.secondColor 		    = None
		self.sixthColor             = None
		self.seventhColor           = None
		self.eighthColor            = None
		self.withTimes 		 		= True
		self.withWorkCost   		= False
		self.withAssignments        = False
		self.iterItem				= None
		self.iterIndex				= 0
		self.iterTitle			    = None
		self.iterTitleIndex	        = 0
		self.iterTask			    = None
		self.iterTaskIndex	        = 0
		self.masterResourcesSortDescriptors		= [NSSortDescriptor.alloc().initWithKey_ascending_("title", True)]
		return self

	def showExpectedValues(self):
		return self.contentMode == 0 

	def topPhases(self):
		return self.project.visibleSubActivitiesArray()
		
	def projectCompleted(self):
		return self.project.isComplete()


		
	def masterResources(self):
		sortedMasterResources = self.project.sortedMasterResources()
		return sortedMasterResources
		
	


	def tasksPerResource(self):
		assignmentValues = {}
		result = NSMutableArray.array()
		result = self.iterItem.valueForKey_("assignments")
		
		byStart = NSSortDescriptor.alloc().initWithKey_ascending_("expectedStartDate", True)
		return result.sortedArrayUsingDescriptors_([byStart])

		
	
	def showObjective(self):
		return self.withObjective and self.project.itemDescription()

	def showResources(self):
		return self.withResources and len(self.resources())>0


	def rowClass(self):
		if self.iterIndex%2:
			return "even"
			
	def rowClassSubRows(self):
		if self.iterTaskIndex%2:
			return "even_var2"


	def listItemClass(self):
		if self.iterIndex == 0:
			return "first"
	
	def dateFormat(self):
		if self.withTimes:
			return "medium/short"
		else:
			return "medium"
			


	
	def intervalStartDates(self):
		start = MEDuration.startOfUnit_containingDate_calendar_(self.intervalUnit, self.project.expectedStartDate(), self.project.sharedNSCalendar())
		end   = self.project.expectedEndDate()
		
		intervalStart = start
		dates = []
		
		while intervalStart<end:
			dates.append(intervalStart)
			intervalStart = MEDuration.endOfUnit_withStartDate_calendar_(self.intervalUnit, intervalStart, self.project.sharedNSCalendar())
			
		return dates
		
	def setIterIntervalStartDate_(self, date):
		self.iterIntervalStartDate = date
		self.iterIntervalEndDate = MEDuration.endOfUnit_withStartDate_calendar_(self.intervalUnit, date, self.project.sharedNSCalendar())
		
		
	def iterIntervalDescription(self):
		return MEDuration.preciseDescriptionForUnit_atDate_calendar_(self.intervalUnit, self.iterIntervalStartDate, self.project.sharedNSCalendar())

	def iterIntervalCalculcationStartDate(self):
		return self.iterIntervalStartDate


	def iterIntervalExpectedWorkPerResource(self):
		if self.iterItem != None:
			a = self.iterItem.expectedWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
			return "%.1f" % a
		else:
			return None


	def expectedWorkPerResource(self):
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		if self.iterItem != None:
			a = self.iterItem.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
			return "%.1f" % a
		else:
			return None

	def actualWorkPerResource(self):
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		if self.iterItem != None:
			a = self.iterItem.actualWorkingUnitsBetweenStartDate_endDate_(start, end)
			return "%.1f" % a
		else:
			return None

	def iterIntervalActualWorkPerResource(self):
		if self.iterItem != None:
			a = self.iterItem.actualWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
			return "%.1f" % a
		else:
			return None
		
	def expectedWorkPerAssignment(self):
		start = self.iterTask.expectedStartDate()
		end = self.iterTask.expectedEndDate()

		if self.iterTask != None:
			a = self.iterTask.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)		
			return "%.1f" % a
		else:
			return None

	def actualWorkPerAssignment(self):
		start = self.iterTask.expectedStartDate()
		end = self.iterTask.expectedEndDate()

		if self.iterTask != None:
			a = self.iterTask.actualWorkingUnitsBetweenStartDate_endDate_(start, end)	
			if a != None:	
				return "%.1f" % a
		else:
			return None


	def iterIntervalExpectedWorkPerAssignment(self):
		if self.iterTask != None:
			a = self.iterTask.expectedWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)		
			return "%.1f" % a
		else:
			return None
			
	def iterIntervalActualWorkPerAssignment(self):
		if self.iterTask != None:
			a = self.iterTask.actualWorkingUnitsBetweenStartDate_endDate_(self.iterIntervalCalculcationStartDate(), self.iterIntervalEndDate)
			return "%.1f" % a
		else:
			return None

	def xTicks(self):
		xTicks = "\"xTicks\": [ "
		res = self.masterResources()		
		for i in range(len(res)):
			cat = res[i].valueForKey_("title")
			if i<len(res)-1:
				separator = ","
			else:
				separator = ""
			titel = cat.replace("\"", "\\\"")
			xTicks += "{v:%d, label:\"%s\"}%s\n" % (i, titel, separator)
		xTicks = xTicks + "]"
		return xTicks



	def workPercentage(self):
		value = 0
		re = self.iterItem
		start = re.expectedStartDate()
		end = re.expectedEndDate()
		if self.showExpectedValues():
			a = re.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
		else:
			a = re.actualWorkingUnitsBetweenStartDate_endDate_(start, end)
		if a != None: 
			value = a
		else:
			value = 0		
		total = self.totalWork()	
		perc = 100 * value / total 	
		return "%.0f" % perc
		
	def totalWork(self):
		result = 0
		start = self.project.expectedStartDate()
		end = self.project.expectedEndDate()
		res = self.masterResources()
		if res != None:
			for re in res:
				if self.showExpectedValues():
					a = re.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
				else:
					a = re.actualWorkingUnitsBetweenStartDate_endDate_(start, end)
				if a != None: 
					result += a
				else:
					result = 0	
		return result
	
		
	def dataSetStringForKey(self, key):
		values = []
		dataSetString = "\"%s\",[" % (key)
		res = self.masterResources()
		for i in range(len(res)):
			re = res[i]
			start = re.expectedStartDate()
			end = re.expectedEndDate()
			if self.showExpectedValues():
				a = re.expectedWorkingUnitsBetweenStartDate_endDate_(start, end)
			else:
				a = re.actualWorkingUnitsBetweenStartDate_endDate_(start, end)
	
			if a != None: 
				value = "%.1f" % a
			else:
				value = 0
			if i<len(res)-1:
				separator = ","
			else:
				separator = ""
			dataSetString += "[%d, %s]%s" % (i, value, separator)
		dataSetString += "]"
		return dataSetString

	def statusStatsDataSetString(self):
		return self.dataSetStringForKey("work")
		
	def firstColorString(self):
		return self.firstColor.webColor()
		
	def secondColorString(self):
		return self.secondColor.webColor()

	def thirdColorString(self):
		return self.thirdColor.webColor()

	def fourthColorString(self):
		return self.fourthColor.webColor()
		
	def fifthColorString(self):
		return self.fifthColor.webColor()

	def sixthColorString(self):
		return self.sixthColor.webColor()
	
	def seventhColorString(self):
		return self.seventhColor.webColor()

	def eighthColorString(self):
		return self.eighthColor.webColor()
